pub struct StringWriter(pub *mut c_char, pub usize);Expand description
An implementation of Write/core::fmt::Write for a byte array.
Tuple Fields
0: *mut c_char1: usizeTrait Implementations
Sourceimpl Write for StringWriter
impl Write for StringWriter
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Write a buffer into this object, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flush this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn write_all(&mut self, buf: &[u8]) -> Result<()>
fn write_all(&mut self, buf: &[u8]) -> Result<()>
Attempts to write an entire buffer into this write. Read more